Python State Machine
====================

Contents:

.. toctree::
   :maxdepth: 2

   readme
   installation
   states
   transitions
   actions
   guards
   observers
   mixins
   integrations
   diagram
   auto_examples/index
   contributing
   authors
   releases/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
